==> estateplat-common-1.2.3-20180123.013116-21-sources.jar: cn/gtmap/estateplat/model/stockHouse/contract/LsFcjyClfMmhtFwjf.java <==
package cn.gtmap.estateplat.model.stockHouse.contract;

import cn.gtmap.estateplat.model.server.core.InsertVo;

import javax.persistence.Id;
import javax.persistence.Table;

/**
 * @author <a href="mailto:liaoxiang@gtmap.cn">liaoxiang</a>
 * @version V1.0, 2017/9/21
 * @description
 */
@Table(name = "ls_fcjy_clf_mmht_fwjf")
public class LsFcjyClfMmhtFwjf implements InsertVo {
    @Id
    private String id;//主键
    private String htid;//合同id
    private String jffs;//交付方式
    private Integer qdhjfr;//签订后交付日
    private Integer mfycxjfr;//买方一次性交付日
    private Integer mfsfkjfr;//买方首付款交付日
    private Integer mfskjfr;//卖方收款交付日
    private String qt;//其他

    public String getHtid() {
        return htid;
    }

    public void setHtid(String htid) {
        this.htid = htid;
    }

    public String getJffs() {
        return jffs;
    }

    public void setJffs(String jffs) {
        this.jffs = jffs;
    }

    public Integer getQdhjfr() {
        return qdhjfr;
    }

    public void setQdhjfr(Integer qdhjfr) {
        this.qdhjfr = qdhjfr;
    }

    public Integer getMfycxjfr() {
        return mfycxjfr;
    }

    public void setMfycxjfr(Integer mfycxjfr) {
        this.mfycxjfr = mfycxjfr;
    }

    public Integer getMfsfkjfr() {
        return mfsfkjfr;
    }

    public void setMfsfkjfr(Integer mfsfkjfr) {
        this.mfsfkjfr = mfsfkjfr;
    }

    public Integer getMfskjfr() {
        return mfskjfr;
    }

    public void setMfskjfr(Integer mfskjfr) {
        this.mfskjfr = mfskjfr;
    }

    public String getQt() {
        return qt;
    }

    public void setQt(String qt) {
        this.qt = qt;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }
}

==> estateplat-common-1.2.4-20240328.072656-1228-sources.jar: cn/gtmap/estateplat/model/stockHouse/contract/LsFcjyClfMmhtFwjf.java <==
package cn.gtmap.estateplat.model.stockHouse.contract;

import cn.gtmap.estateplat.model.server.core.InsertVo;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:liaoxiang@gtmap.cn">liaoxiang</a>
 * @version V1.0, 2017/9/21
 * @description
 */
@Table(name = "ls_fcjy_clf_mmht_fwjf")
public class LsFcjyClfMmhtFwjf implements InsertVo {
    @Id
    private String id;//主键
    private String htid;//合同id
    private String jffs;//交付方式
    private Integer qdhjfr;//签订后交付日
    private Integer mfycxjfr;//买方一次性交付日
    private Integer mfsfkjfr;//买方首付款交付日
    private Integer mfskjfr;//卖方收款交付日
    private String qt;//其他
    private Date fwjfrq;//房屋交付日期
    private Date ghrq;//过户日期

    public String getHtid() {
        return htid;
    }

    public void setHtid(String htid) {
        this.htid = htid;
    }

    public String getJffs() {
        return jffs;
    }

    public void setJffs(String jffs) {
        this.jffs = jffs;
    }

    public Integer getQdhjfr() {
        return qdhjfr;
    }

    public void setQdhjfr(Integer qdhjfr) {
        this.qdhjfr = qdhjfr;
    }

    public Integer getMfycxjfr() {
        return mfycxjfr;
    }

    public void setMfycxjfr(Integer mfycxjfr) {
        this.mfycxjfr = mfycxjfr;
    }

    public Integer getMfsfkjfr() {
        return mfsfkjfr;
    }

    public void setMfsfkjfr(Integer mfsfkjfr) {
        this.mfsfkjfr = mfsfkjfr;
    }

    public Integer getMfskjfr() {
        return mfskjfr;
    }

    public void setMfskjfr(Integer mfskjfr) {
        this.mfskjfr = mfskjfr;
    }

    public String getQt() {
        return qt;
    }

    public void setQt(String qt) {
        this.qt = qt;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public Date getFwjfrq() {
        return fwjfrq;
    }

    public void setFwjfrq(Date fwjfrq) {
        this.fwjfrq = fwjfrq;
    }

    public Date getGhrq() {
        return ghrq;
    }

    public void setGhrq(Date ghrq) {
        this.ghrq = ghrq;
    }
}
